==> blueprint-component-mapper-3.1.1.tgz: package/esm/wizard/wizard.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import WizardCommon from '@data-driven-forms/common/wizard/wizard';
import FormSpy from "@data-driven-forms/react-form-renderer/form-spy";
import WizardContext from "@data-driven-forms/react-form-renderer/wizard-context";
import StepButtons from './step-buttons';

var WizardInternal = function WizardInternal(_ref) {
  var WizardProps = _ref.WizardProps,
      props = _objectWithoutProperties(_ref, ["WizardProps"]);

  var _useContext = useContext(WizardContext),
      formOptions = _useContext.formOptions,
      currentStep = _useContext.currentStep,
      onKeyDown = _useContext.onKeyDown,
      rest = _objectWithoutProperties(_useContext, ["formOptions", "currentStep", "onKeyDown"]);

  return /*#__PURE__*/React.createElement("div", _extends({
    onKeyDown: onKeyDown
  }, WizardProps), currentStep.fields.map(function (item) {
    return formOptions.renderForm([item], formOptions);
  }), /*#__PURE__*/React.createElement(FormSpy, {
    subscription: {
      valid: true,
      submitting: true,
      validating: true
    }
  }, function (_ref2) {
    var valid = _ref2.valid,
        submitting = _ref2.submitting,
        validating = _ref2.validating;
    return /*#__PURE__*/React.createElement(StepButtons, _extends({
      isNextDisabled: !valid || submitting || validating
    }, props, rest, {
      currentStep: currentStep,
      formOptions: formOptions
    }));
  }));
};

WizardInternal.propTypes = {
  WizardProps: PropTypes.object
};
var defaultLabels = {
  submit: 'Submit',
  cancel: 'Cancel',
  back: 'Back',
  next: 'Next'
};

var Wizard = function Wizard(_ref3) {
  var buttonLabels = _ref3.buttonLabels,
      props = _objectWithoutProperties(_ref3, ["buttonLabels"]);

  return /*#__PURE__*/React.createElement(WizardCommon, _extends({
    Wizard: WizardInternal
  }, props, {
    buttonLabels: _objectSpread(_objectSpread({}, defaultLabels), buttonLabels)
  }));
};

Wizard.propTypes = {
  buttonLabels: PropTypes.object
};
export default Wizard;

==> blueprint-component-mapper-3.6.0.tgz: package/esm/wizard/wizard.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import WizardCommon from '@data-driven-forms/common/wizard/wizard';
import FormSpy from "@data-driven-forms/react-form-renderer/form-spy";
import WizardContext from "@data-driven-forms/react-form-renderer/wizard-context";
import StepButtons from './step-buttons';

var WizardInternal = function WizardInternal(_ref) {
  var WizardProps = _ref.WizardProps,
      props = _objectWithoutProperties(_ref, ["WizardProps"]);

  var _useContext = useContext(WizardContext),
      formOptions = _useContext.formOptions,
      currentStep = _useContext.currentStep,
      onKeyDown = _useContext.onKeyDown,
      rest = _objectWithoutProperties(_useContext, ["formOptions", "currentStep", "onKeyDown"]);

  return /*#__PURE__*/React.createElement("div", _extends({
    onKeyDown: onKeyDown
  }, WizardProps), currentStep.fields.map(function (item) {
    return formOptions.renderForm([item], formOptions);
  }), /*#__PURE__*/React.createElement(FormSpy, null, function (_ref2) {
    var valid = _ref2.valid,
        submitting = _ref2.submitting,
        validating = _ref2.validating;
    return /*#__PURE__*/React.createElement(StepButtons, _extends({
      isNextDisabled: !valid || submitting || validating
    }, props, rest, {
      currentStep: currentStep,
      formOptions: formOptions
    }));
  }));
};

WizardInternal.propTypes = {
  WizardProps: PropTypes.object
};
var defaultLabels = {
  submit: 'Submit',
  cancel: 'Cancel',
  back: 'Back',
  next: 'Next'
};

var Wizard = function Wizard(_ref3) {
  var buttonLabels = _ref3.buttonLabels,
      props = _objectWithoutProperties(_ref3, ["buttonLabels"]);

  return /*#__PURE__*/React.createElement(WizardCommon, _extends({
    Wizard: WizardInternal
  }, props, {
    buttonLabels: _objectSpread(_objectSpread({}, defaultLabels), buttonLabels)
  }));
};

Wizard.propTypes = {
  buttonLabels: PropTypes.object
};
export default Wizard;
